################################################################################
#  Replace ... by the location where scripts and datasets are saved            #
################################################################################

filepath=".../"

################################################################################
#  Source/load all scripts, librairies and datasets                            #
################################################################################

library(nlme)
library(lattice)

source(paste(filepath,"Chapter4_functions.r",sep=""))

load(paste(filepath,"Chapter4.rdata",sep=""))

################################################################################
#  Skin resistance data                                                        #
################################################################################
#
# set contrasts
options(contrasts=c("contr.sum","cont.poly"))
#
#Electrode data with subject 15 removed

Electrode_15=Electrode[-c(71,72,73,74,75),]

#
#       ##############
#       # Figure 4.1 #
#       ##############
#

interaction.plot(Electrode$Elec,Electrode$Subject,Electrode$Resis,xlab="Resistance",
ylab="Electrode Type",trace.label="Subject")

#
#       #############
#       # Table 4.1 #
#       #############
#

Elec.lme=lme(Resis/100~Elec,data=Electrode,random=~1|Subject,method="REML")
summary(Elec.lme)

Elec.lme15=lme(Resis/100~Elec,data=Electrode_15,random=~1|Subject,method="REML")
summary(Elec.lme15)

#
#       #############
#       # Table 4.3 #
#       #############
#

#
# REML

Elec.lme=lme(Resis/100~Elec,data=Electrode,random=~1|Subject,method="REML")
summary(Elec.lme)

#
# Robust

Elec.lmeRob=lmeRob(Resis/100~Elec,data=Electrode,random=~1|Subject)
summary(Elec.lmeRob)

#
#       ##############
#       # Figure 4.1 #
#       ##############
#

interaction.plot(Electrode$Elec,Electrode$Subject,log(Electrode$Resis),xlab="Resistance",
ylab="Electrode Type",trace.label="Subject")

#
#       #############
#       # Table 4.4 #
#       #############
#

#
# REML

LogElec.lme=lme(log(Resis)~Elec,data=Electrode,random=~1|Subject,method="REML")
summary(LogElec.lme)

#
# Robust

LogElec.lmeRob=lmeRob(log(Resis)~Elec,data=Electrode,random=~1|Subject)
summary(LogElec.lmeRob)

#
#       ##############
#       # Figure 4.4 #
#       ##############
#
x11()
plot(Elec.lmeRob)


#
#       ##############
#       # Figure 4.5 #
#       ##############
#
x11()
plot(LogElec.lmeRob)

#
#       ##############
#       # Figure 4.8 #
#       ##############
#

Elec.lmeRob.ranef=ranef.lmeRob(Elec.lmeRob)
x11()
plot(Elec.lmeRob.ranef)


#
#       ##############
#       # Figure 4.9 #
#       ##############
#
x11()
opt=residuals(Elec.lmeRob) 
plot(opt)
 



################################################################################
#  Semantic priming data                                                       #
################################################################################


#
#       #############
#       # Table 4.4 #
#       #############
#
#
# REML

Semantic.lme  <- lme(fixed=Resp~Delay*Condition,data=Semantic,
random=list(Subject=pdBlocked(list(pdIdent(~1),pdIdent(~Delay-1),pdIdent(~Condition-1)))),
method="REML")
summary(Semantic.lme)

#
# Robust

Semantic.lmeRob <- lmeRob(fixed=Resp~Delay*Condition,data=Semantic,
random=~Condition+Delay|Subject)
summary(Semantic.lmeRob)

#
#       #############
#       # Table 4.6 #
#       #############
#
#
# REML
anova(Semantic.lme)

#
# Robust

anova(Semantic.lmeRob)

#
#       #############
#       # Table 4.7 #
#       #############
#
#
# REML

LogSemantic.lme  <- lme(fixed=log(Resp)~Delay*Condition,data=Semantic,
random=list(Subject=pdBlocked(list(pdIdent(~1),pdIdent(~Delay-1),pdIdent(~Condition-1)))),
method="REML")
summary(LogSemantic.lme)

#
# Robust

LogSemantic.lmeRob <- lmeRob(fixed=log(Resp)~Delay*Condition,data=Semantic,
random=~Condition+Delay|Subject)
summary(LogSemantic.lmeRob)

#
#       #############
#       # Table 4.8 #
#       #############
#
#
# REML
anova(LogSemantic.lme)
 

#
# Robust

anova(LogSemantic.lmeRob)

#
#       ##############
#       # Figure 4.6 #
#       ##############
#

x11()
plot(Semantic.lmeRob)


#
#       ##############
#       # Figure 4.7 #
#       ##############
#

x11()
plot(LogSemantic.lmeRob)


################################################################################
#  Metallic Oxide data                                                         #
################################################################################


#
#       ###############
#       # Figure 4.10 #
#       ###############
#

xyplot(Lots~Response|Sample*Chemist,groups=Type,data=Metal,auto.key=T,xlab="
Metal content (percent by weight)")


#
#       ###############
#       # Table 4.9   #
#       ###############
#

Metal.lmeRob <- lmeRob(Response~Type,data=Metal,random=~1|Lots/Sample/Chemist)
summary(Metal.lmeRob)

#
#       ###############
#       # Table 4.11  #
#       ###############
#

x11()
plot(Metal.lmeRob)

################################################################################
#  Orthodontic Growth data                                                     #
################################################################################

#
#       ##############
#       # Figure 4.2 #
#       ##############
#

Dental=groupedData( distance ~ age | Subject,
              data = as.data.frame( Dental ),
              FUN = mean,
              outer = ~ Sex,
              labels = list( x = "Age",
                y = "Distance from pituitary to pterygomaxillary fissure" ),
              units = list( x = "(yr)", y = "(mm)") )


Dental.lme <- lme(distance~Sex*age, data = Dental,random = ~ age | Subject)

x11()              
plot(augPred(Dental.lme))

#
#       ##############
#       # Table 4.10 #
#       ##############
#



Dental.lmeRob <- lmeRob(distance~Sex*age, data = Dental,random = ~ age | Subject)
summary(Dental.lmeRob)  


#
#       ###############
#       # Figure 4.12 #
#       ###############
#

x11()
plot(Dental.lme,resid(.,type="p")~fitted(.)|Sex,id=0.05,adj=-0.3)

#
#       ###############
#       # Figure 4.13 #
#       ###############
#


Dental.lmeRob.ranef=ranef.lmeRob(Dental.lmeRob)
x11()
plot(Dental.lmeRob.ranef)

#
#       ###############
#       # Figure 4.14 #
#       ###############
#

opt=residuals(Dental.lmeRob)
plot(opt) 
